@@ -4,14 +4,11 @@
 
 import src.api.global_
 from src.api.constants import TYPE
-from src.arch.z80 import optimizer  # noqa
-from src.arch.z80 import beep
-from src.arch.z80.translator import *  # noqa
+from src.arch.z80 import FunctionTranslator, Translator, VarTranslator, beep
 from src.arch.zxnext import backend  # noqa
+from src.arch.zxnext import optimizer  # noqa
 
-__all__ = [
-    "beep",
-]
+__all__ = "beep", "VarTranslator", "FunctionTranslator", "Translator"
 
 
 # -----------------------------------------
@@ -24,3 +21,5 @@ src.api.global_.PTR_TYPE = TYPE.uinteger
 src.api.global_.STR_INDEX_TYPE = TYPE.uinteger
 src.api.global_.MIN_STRSLICE_IDX = 0  # Min. string slicing position
 src.api.global_.MAX_STRSLICE_IDX = 65534  # Max. string slicing position
+
+backend.Backend()
